<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>ConvertToSQLiteDialog</name>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="26"/>
        <source>Import BAM File</source>
        <translation>Импорт BAM файла</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="34"/>
        <source>Source URL:</source>
        <translation>Путь до данных:</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="48"/>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="55"/>
        <source>Reference:</source>
        <translation>Референс:</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="69"/>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="193"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;The SAM file does not contain the header. Please, choose the reference sequence.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;SAM файл не может содержать заголовок. Выберите референсную последовательность.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Index file (*.bai) is not available. Partial import is going to be slowed down.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Индексный файл (*.bai) недоступен.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message utf8="true">
        <location filename="../src/ConvertToSQLiteDialog.ui" line="84"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;left&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Input SAM file does not contain a header. Сhoose a file with reference sequences or references info will be generated.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;left&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;SAM файл не содержит заголовка. Выберите референсную последовательность.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="98"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;left&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Index file (*.bai) is not available. Partial import is going to be slowed down.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;left&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Индексный файл (*.bai) недоступен.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="137"/>
        <source>Select All</source>
        <translation>Выбрать все</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="144"/>
        <source>Deselect All</source>
        <translation>Снять выбор со всех</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="151"/>
        <source>Invert Selection</source>
        <translation>Инвертировать выделение</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="174"/>
        <source>Import unmapped reads</source>
        <translation>Импорт несопоставленных ридов</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="183"/>
        <source>Destination URL:</source>
        <translation>Путь для сохранения:</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.ui" line="204"/>
        <source>Add to project</source>
        <translation>Добавить в проект</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="247"/>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="250"/>
        <source>Reference File</source>
        <translation>Референсный файл</translation>
    </message>
</context>
<context>
    <name>U2::BAM::BAMDbiPlugin</name>
    <message>
        <location filename="../src/BaiReader.cpp" line="43"/>
        <location filename="../src/Reader.cpp" line="433"/>
        <source>Invalid magic number</source>
        <translation>Invalid magic number</translation>
    </message>
    <message>
        <location filename="../src/BaiReader.cpp" line="48"/>
        <location filename="../src/Reader.cpp" line="448"/>
        <source>Invalid number of references: %1</source>
        <translation>Invalid number of references: %1</translation>
    </message>
    <message>
        <location filename="../src/BaiReader.cpp" line="54"/>
        <source>Invalid number of bins: %1</source>
        <translation>Invalid number of bins: %1</translation>
    </message>
    <message>
        <location filename="../src/BaiReader.cpp" line="61"/>
        <source>Invalid number of chunks: %1</source>
        <translation>Invalid number of chunks: %1</translation>
    </message>
    <message>
        <location filename="../src/BaiReader.cpp" line="79"/>
        <source>Invalid number of intervals: %1</source>
        <translation>Invalid number of intervals: %1</translation>
    </message>
    <message>
        <location filename="../src/BaiReader.cpp" line="94"/>
        <source>Can&apos;t read input. %1</source>
        <translation>Can&apos;t read input. %1</translation>
    </message>
    <message>
        <location filename="../src/BaiReader.cpp" line="96"/>
        <location filename="../src/BgzfReader.cpp" line="121"/>
        <location filename="../src/BgzfReader.cpp" line="143"/>
        <location filename="../src/Reader.cpp" line="350"/>
        <source>Unexpected end of file</source>
        <translation>Unexpected end of file</translation>
    </message>
    <message>
        <location filename="../src/BaiWriter.cpp" line="59"/>
        <location filename="../src/BgzfWriter.cpp" line="74"/>
        <location filename="../src/BgzfWriter.cpp" line="106"/>
        <source>Can&apos;t write output</source>
        <translation>Can&apos;t write output</translation>
    </message>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="73"/>
        <source>BAM format support</source>
        <translation>Поддержка формата BAM</translation>
    </message>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="73"/>
        <source>Interface for indexed read-only access to BAM files</source>
        <translation>Поддержка формата BAM</translation>
    </message>
    <message>
        <location filename="../src/BgzfReader.cpp" line="43"/>
        <location filename="../src/BgzfWriter.cpp" line="43"/>
        <source>Can&apos;t initialize zlib</source>
        <translation>Can&apos;t initialize zlib</translation>
    </message>
    <message>
        <location filename="../src/BgzfReader.cpp" line="65"/>
        <location filename="../src/BgzfReader.cpp" line="130"/>
        <location filename="../src/BgzfReader.cpp" line="160"/>
        <source>Can&apos;t read input</source>
        <translation>Can&apos;t read input</translation>
    </message>
    <message>
        <location filename="../src/BgzfReader.cpp" line="81"/>
        <location filename="../src/BgzfReader.cpp" line="179"/>
        <source>Can&apos;t decompress data</source>
        <translation>Can&apos;t decompress data</translation>
    </message>
    <message>
        <location filename="../src/BgzfWriter.cpp" line="70"/>
        <location filename="../src/BgzfWriter.cpp" line="112"/>
        <source>Can&apos;t compress data</source>
        <translation>Can&apos;t compress data</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="26"/>
        <source>Hard clip in the middle of cigar</source>
        <translation>Hard clip in the middle of cigar</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="36"/>
        <source>Misplaced soft clip in the cigar: must be preceded with hard clip</source>
        <translation>Misplaced soft clip in the cigar: must be preceded with hard clip</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="40"/>
        <source>Misplaced soft clip in the cigar: must be succeeded with hard clip</source>
        <translation>Misplaced soft clip in the cigar: must be succeeded with hard clip</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="43"/>
        <source>Misplaced soft clip in the cigar: can&apos;t be in the middle of the string</source>
        <translation>Misplaced soft clip in the cigar: can&apos;t be in the middle of the string</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="65"/>
        <source>No match or skip operation between adjacent in/del/skip operations</source>
        <translation>No match or skip operation between adjacent in/del/skip operations</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="72"/>
        <source>CIGAR can&apos;t start or end with padding operator</source>
        <translation>CIGAR can&apos;t start or end with padding operator</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="74"/>
        <source>Padding operator must be located between real operations</source>
        <translation>Padding operator must be located between real operations</translation>
    </message>
    <message>
        <location filename="../src/CigarValidator.cpp" line="93"/>
        <source>CIGAR must contain at least one real operation (ins/del/match/skip)</source>
        <translation>CIGAR must contain at least one real operation (ins/del/match/skip)</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="82"/>
        <source>Assembly name</source>
        <translation>Имя сборки</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="82"/>
        <source>Length</source>
        <translation>Длина</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="82"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="146"/>
        <source>%1 file info</source>
        <translation>%1 file info</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="152"/>
        <source>Property name</source>
        <translation>Имя свойства</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="152"/>
        <source>Value</source>
        <translation>Значение</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="159"/>
        <source>Unsorted</source>
        <translation>Несортированный</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="160"/>
        <source>Unknown</source>
        <translation>Неизвестный</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="161"/>
        <source>Coordinate</source>
        <translation>Координата</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="162"/>
        <source>Query name</source>
        <translation>Имя запроса</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="165"/>
        <source>URL</source>
        <translation>Путь</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="166"/>
        <source>Format version</source>
        <translation>Версия формата</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="167"/>
        <source>Sorting order</source>
        <translation>Порядок сортировки</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="187"/>
        <source>Sequencing center</source>
        <translation>Центр секвенирования</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="187"/>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="187"/>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="188"/>
        <source>Library</source>
        <translation>Библиотека</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="188"/>
        <source>Programs</source>
        <translation>Программы</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="188"/>
        <source>Predicted median insert size</source>
        <translation>Прогнозируемый средний размер вставки</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="188"/>
        <source>Platform/technology</source>
        <translation>Платформа/технология</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="189"/>
        <source>Platform unit</source>
        <translation>Блок платформы</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="189"/>
        <source>Sample</source>
        <translation>Пример</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="206"/>
        <source>Read groups:</source>
        <translation>Группы ридов:</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="213"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="213"/>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="213"/>
        <source>Command</source>
        <translation>Команда</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="213"/>
        <source>Previous ID</source>
        <translation>Предыдущий идентификатор</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="229"/>
        <source>Programs:</source>
        <translation>Программы:</translation>
    </message>
    <message>
        <source>Please select the file with the reference sequence</source>
        <translation type="obsolete">Выберите файл с референсной последовательностью</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="293"/>
        <source>Please select assemblies to be imported</source>
        <translation>Выберите сборку, которая будет импортирована</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="316"/>
        <source>Destination URL is not specified</source>
        <translation>Путь для сохранения не указан</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="319"/>
        <source>Destination URL must point to a local file</source>
        <translation>Путь должен указывать на локальный файл</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="322"/>
        <source>Destination URL folder has not write permissions</source>
        <translation>Нет прав на запись в указанную папку</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="332"/>
        <source>There is opened view with destination file.
Close it or choose different file</source>
        <translation>Указанный файл открыт. Закройте его или укажите другой файл</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="341"/>
        <source>Destination folder &apos;%1&apos; is not writable, please choose different destination URL</source>
        <translation>Невозможно записать в указанную папку &apos;%1&apos; , укажите другую папку</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="347"/>
        <source>Destination file already exists.
To overwrite the file, press &apos;Replace&apos;.
To append data to existing file press &apos;Append&apos;.</source>
        <translation>Указанный файл уже существует.
Чтобы переписать файл выберите &apos;Переписать&apos;.
Чтобы добавить данные к существующему файлу выберите &apos;Добавить&apos;.</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="350"/>
        <source>Replace</source>
        <translation>Переписать</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="351"/>
        <source>Append</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="352"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="358"/>
        <source>Destination file &apos;%1&apos; cannot be removed</source>
        <translation>Файл &apos;%1&apos; не может быть удален</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="381"/>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="384"/>
        <source>Destination UGENEDB File</source>
        <translation>Destination UGENEDB File</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="381"/>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="384"/>
        <source>UGENEDB Files (*.ugenedb);;All Files (*)</source>
        <translation>UGENEDB Files (*.ugenedb);;All Files (*)</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="88"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="103"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="117"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="132"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="166"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="182"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="196"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="229"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="236"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="243"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="250"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="275"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="283"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="291"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="299"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="355"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="364"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="411"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="418"/>
        <source>The iteration has no next element</source>
        <translation>The iteration has no next element</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="348"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="631"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="644"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="691"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="738"/>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="765"/>
        <source>Task was cancelled</source>
        <translation>Task was cancelled</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="50"/>
        <location filename="../src/Dbi.cpp" line="123"/>
        <location filename="../src/Dbi.cpp" line="145"/>
        <location filename="../src/Dbi.cpp" line="370"/>
        <location filename="../src/Dbi.cpp" line="388"/>
        <location filename="../src/Dbi.cpp" line="414"/>
        <location filename="../src/Dbi.cpp" line="433"/>
        <location filename="../src/Dbi.cpp" line="445"/>
        <location filename="../src/Dbi.cpp" line="457"/>
        <location filename="../src/Dbi.cpp" line="472"/>
        <location filename="../src/Dbi.cpp" line="487"/>
        <location filename="../src/Dbi.cpp" line="503"/>
        <location filename="../src/Dbi.cpp" line="515"/>
        <location filename="../src/Dbi.cpp" line="530"/>
        <location filename="../src/Dbi.cpp" line="568"/>
        <location filename="../src/Dbi.cpp" line="588"/>
        <location filename="../src/Dbi.cpp" line="616"/>
        <location filename="../src/Dbi.cpp" line="657"/>
        <location filename="../src/Dbi.cpp" line="690"/>
        <location filename="../src/Dbi.cpp" line="718"/>
        <location filename="../src/Dbi.cpp" line="765"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="72"/>
        <source>Invalid DBI state</source>
        <translation>Invalid DBI state</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="54"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="76"/>
        <source>URL is not specified</source>
        <translation>URL is not specified</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="58"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="80"/>
        <source>Non-local files are not supported</source>
        <translation>Non-local files are not supported</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="65"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="114"/>
        <source>Can&apos;t open file &apos;%1&apos;</source>
        <translation>Can&apos;t open file &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="76"/>
        <source>Can&apos;t open index database</source>
        <translation>Can&apos;t open index database</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="294"/>
        <source>Operation was cancelled</source>
        <translation>Operation was cancelled</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="460"/>
        <location filename="../src/Dbi.cpp" line="475"/>
        <location filename="../src/Dbi.cpp" line="518"/>
        <location filename="../src/Dbi.cpp" line="533"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="296"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="306"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="334"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="344"/>
        <source>No such folder: %1</source>
        <translation>No such folder: %1</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="571"/>
        <location filename="../src/Dbi.cpp" line="591"/>
        <location filename="../src/Dbi.cpp" line="619"/>
        <location filename="../src/Dbi.cpp" line="693"/>
        <location filename="../src/Dbi.cpp" line="721"/>
        <location filename="../src/Dbi.cpp" line="768"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="561"/>
        <source>The specified object is not an assembly</source>
        <translation>The specified object is not an assembly</translation>
    </message>
    <message>
        <location filename="../src/Dbi.cpp" line="660"/>
        <source>The specified object is not an assembly read</source>
        <translation>The specified object is not an assembly read</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="84"/>
        <location filename="../src/SamReader.cpp" line="122"/>
        <source>Invalid read position: %1</source>
        <translation>Invalid read position: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="145"/>
        <source>Invalid mate reference id: %1</source>
        <translation>Invalid mate reference id: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="153"/>
        <location filename="../src/SamReader.cpp" line="214"/>
        <source>Invalid mate position: %1</source>
        <translation>Invalid mate position: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="161"/>
        <source>Invalid template length of a sigle-fragment template: %1</source>
        <translation>Invalid template length of a sigle-fragment template: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="202"/>
        <location filename="../src/SamReader.cpp" line="181"/>
        <source>Invalid cigar operation code: %1</source>
        <translation>Invalid cigar operation code: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="323"/>
        <source>Invalid block size: %1</source>
        <translation>Invalid block size: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="327"/>
        <source>Invalid reference id: %1</source>
        <translation>Invalid reference id: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="440"/>
        <source>Invalid header text size: %1</source>
        <translation>Invalid header text size: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="455"/>
        <source>Invalid reference name length: %1</source>
        <translation>Invalid reference name length: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="460"/>
        <location filename="../src/SamReader.cpp" line="104"/>
        <source>Invalid reference name: %1</source>
        <translation>Invalid reference name: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="465"/>
        <source>Invalid reference sequence length: %1</source>
        <translation>Invalid reference sequence length: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="483"/>
        <source>Invalid header line: %1</source>
        <translation>Invalid header line: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="491"/>
        <location filename="../src/SamReader.cpp" line="343"/>
        <source>Invalid header record tag: %1</source>
        <translation>Invalid header record tag: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="504"/>
        <location filename="../src/SamReader.cpp" line="356"/>
        <source>Invalid header field: %1</source>
        <translation>Invalid header field: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="508"/>
        <location filename="../src/SamReader.cpp" line="360"/>
        <source>Invalid header field tag: %1</source>
        <translation>Invalid header field tag: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="512"/>
        <location filename="../src/SamReader.cpp" line="364"/>
        <source>Invalid %1-%2 value: %3</source>
        <translation>Invalid %1-%2 value: %3</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="517"/>
        <location filename="../src/SamReader.cpp" line="369"/>
        <source>Duplicate header field: %1</source>
        <translation>Duplicate header field: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="530"/>
        <location filename="../src/SamReader.cpp" line="382"/>
        <source>HD record without VN field</source>
        <translation>HD record without VN field</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="545"/>
        <location filename="../src/SamReader.cpp" line="397"/>
        <source>Invalid HD-SO value: %1</source>
        <translation>Invalid HD-SO value: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="555"/>
        <source>Unmatched SQ-SN value: %1</source>
        <translation>Unmatched SQ-SN value: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="558"/>
        <location filename="../src/SamReader.cpp" line="408"/>
        <source>SQ record without SN field</source>
        <translation>SQ record without SN field</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="566"/>
        <source>SQ-LN value mismatch: %1 != %2</source>
        <translation>SQ-LN value mismatch: %1 != %2</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="569"/>
        <location filename="../src/SamReader.cpp" line="420"/>
        <source>Invalid SQ-LN value: %1</source>
        <translation>Invalid SQ-LN value: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="572"/>
        <location filename="../src/SamReader.cpp" line="423"/>
        <source>SQ record without LN field</source>
        <translation>SQ record without LN field</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="581"/>
        <location filename="../src/SamReader.cpp" line="433"/>
        <source>Invalid SQ-M5 value: %1</source>
        <translation>Invalid SQ-M5 value: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="633"/>
        <location filename="../src/SamReader.cpp" line="485"/>
        <source>Invalid RG-PI field value: %1</source>
        <translation>Invalid RG-PI field value: %1</translation>
    </message>
    <message>
        <location filename="../src/Reader.cpp" line="675"/>
        <location filename="../src/SamReader.cpp" line="527"/>
        <source>Invalid PG-PP field value: %1</source>
        <translation>Invalid PG-PP field value: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="40"/>
        <source>Unexpected empty string</source>
        <translation>Unexpected empty string</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="47"/>
        <source>Not enough fields in one of alignments</source>
        <translation>Not enough fields in one of alignments</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="54"/>
        <source>Invalid query template name: %1</source>
        <translation>Invalid query template name: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="62"/>
        <source>Invalid FLAG value: %1</source>
        <translation>Invalid FLAG value: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="110"/>
        <source>Undefined reference name: %1</source>
        <translation>Undefined reference name: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="119"/>
        <source>Invalid read position value: %1</source>
        <translation>Invalid read position value: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="130"/>
        <source>Invalid mapping quality value: %1</source>
        <translation>Invalid mapping quality value: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="133"/>
        <source>Invalid mapping quality: %1</source>
        <translation>Invalid mapping quality: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="140"/>
        <location filename="../src/SamReader.cpp" line="146"/>
        <source>Invalid cigar value: %1</source>
        <translation>Invalid cigar value: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="193"/>
        <source>Invalid mate reference name: %1</source>
        <translation>Invalid mate reference name: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="201"/>
        <source>Undefined mate reference name: %1</source>
        <translation>Undefined mate reference name: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="211"/>
        <source>Invalid mate position value: %1</source>
        <translation>Invalid mate position value: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="222"/>
        <source>Invalid template length value: %1</source>
        <translation>Invalid template length value: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="226"/>
        <source>Invalid template length of a single-fragment template: %1</source>
        <translation>Invalid template length of a single-fragment template: %1</translation>
    </message>
    <message>
        <location filename="../src/SamReader.cpp" line="234"/>
        <source>Invalid sequence: %1</source>
        <translation>Invalid sequence: %1</translation>
    </message>
    <message>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="90"/>
        <source>Can&apos;t build index for: %1</source>
        <translation>Can&apos;t build index for: %1</translation>
    </message>
    <message>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="124"/>
        <source>Can&apos;t load index file for &apos;%1&apos;</source>
        <translation>Can&apos;t load index file for &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="129"/>
        <source>Can&apos;t read header from file &apos;%1&apos;</source>
        <translation>Can&apos;t read header from file &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="234"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="246"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="253"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="265"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="281"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="287"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="293"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="303"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="313"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="324"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="331"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="341"/>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="555"/>
        <source>Invalid samtools DBI state</source>
        <translation>Invalid samtools DBI state</translation>
    </message>
    <message>
        <location filename="../src/SamtoolsBasedDbi.cpp" line="255"/>
        <source>Object not found</source>
        <translation>Object not found</translation>
    </message>
</context>
<context>
    <name>U2::BAM::BAMImporter</name>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="85"/>
        <source>BAM/SAM file import</source>
        <translation>Импорт BAM/SAM файлов</translation>
    </message>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="96"/>
        <source>BAM files importer is used to convert conventional BAM and SAM files into UGENE database format. Having BAM or SAM file converted into UGENE DB format you get an fast and efficient interface to your data with an option to change the content</source>
        <translation>Импорт BAM файлов используется для того, чтобы конвертировать BAM и SAM файлы в формат базы данных UGENE</translation>
    </message>
</context>
<context>
    <name>U2::BAM::BAMImporterTask</name>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="125"/>
        <source>BAM/SAM file import: %1</source>
        <translation>BAM/SAM file import: %1</translation>
    </message>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="234"/>
        <source>Can&apos;t create a temporary database</source>
        <translation>Can&apos;t create a temporary database</translation>
    </message>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="257"/>
        <source>SAM cannot be converted to BAM: neither reference nor header in SAM file is present</source>
        <translation>SAM cannot be converted to BAM: neither reference nor header in SAM file is present</translation>
    </message>
    <message>
        <location filename="../src/BAMDbiPlugin.cpp" line="305"/>
        <source>Failed to get load task for : %1</source>
        <translation>Failed to get load task for : %1</translation>
    </message>
</context>
<context>
    <name>U2::BAM::ConvertToSQLiteDialog</name>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="53"/>
        <source>Import</source>
        <translation>Импорт</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="57"/>
        <source>Import SAM File</source>
        <translation>Импорт SAM файла</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="59"/>
        <location filename="../src/ConvertToSQLiteDialog.cpp" line="61"/>
        <source>Import BAM File</source>
        <translation>Импорт BAM файла</translation>
    </message>
</context>
<context>
    <name>U2::BAM::ConvertToSQLiteTask</name>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="53"/>
        <source>Convert BAM to UGENE database (%1)</source>
        <translation>Convert BAM to UGENE database (%1)</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="439"/>
        <source>Converting assembly from %1 to %2 started</source>
        <translation>Converting assembly from %1 to %2 started</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="474"/>
        <source>Converting assembly from %1 to %2 cancelled</source>
        <translation>Converting assembly from %1 to %2 cancelled</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="480"/>
        <source>Converting assembly from %1 to %2 failed: %3</source>
        <translation>Converting assembly from %1 to %2 failed: %3</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="549"/>
        <source>Packing reads for assembly &apos;%1&apos; (%2 of %3)</source>
        <translation>Packing reads for assembly &apos;%1&apos; (%2 of %3)</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="613"/>
        <source>Importing assembly &apos;%1&apos; (%2 of %3)</source>
        <translation>Importing assembly &apos;%1&apos; (%2 of %3)</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="634"/>
        <source>Successfully imported %1 reads for assembly &apos;%2&apos; (total %3 reads imported)</source>
        <translation>Successfully imported %1 reads for assembly &apos;%2&apos; (total %3 reads imported)</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="654"/>
        <source>Importing unmapped reads</source>
        <translation>Importing unmapped reads</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="697"/>
        <source>No bam index given, preparing sequential import</source>
        <translation>No bam index given, preparing sequential import</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="709"/>
        <source>Importing reads sequentially</source>
        <translation>Importing reads sequentially</translation>
    </message>
    <message>
        <location filename="../src/ConvertToSQLiteTask.cpp" line="864"/>
        <source>Warning: incorrect maxProw == %1, probably packing was not done! Attribute was not set</source>
        <translation>Warning: incorrect maxProw == %1, probably packing was not done! Attribute was not set</translation>
    </message>
</context>
<context>
    <name>U2::BAM::LoadInfoTask</name>
    <message>
        <location filename="../src/LoadBamInfoTask.cpp" line="39"/>
        <source>Load BAM info</source>
        <translation>Load BAM info</translation>
    </message>
    <message>
        <location filename="../src/LoadBamInfoTask.cpp" line="63"/>
        <source>Can&apos;t open file &apos;%1&apos;</source>
        <translation>Can&apos;t open file &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/LoadBamInfoTask.cpp" line="94"/>
        <source>Loading BAM info for file &apos;%1&apos; failed: %2</source>
        <translation>Loading BAM info for file &apos;%1&apos; failed: %2</translation>
    </message>
    <message>
        <location filename="../src/PrepareToImportTask.cpp" line="68"/>
        <source>Can not copy the &apos;%1&apos; file to &apos;%2&apos;</source>
        <translation>Can not copy the &apos;%1&apos; file to &apos;%2&apos;</translation>
    </message>
    <message>
        <location filename="../src/PrepareToImportTask.cpp" line="91"/>
        <source>Converting SAM to BAM</source>
        <translation>Converting SAM to BAM</translation>
    </message>
    <message>
        <location filename="../src/PrepareToImportTask.cpp" line="111"/>
        <source>Sorting BAM</source>
        <translation>Sorting BAM</translation>
    </message>
    <message>
        <location filename="../src/PrepareToImportTask.cpp" line="128"/>
        <source>Coping sorted BAM</source>
        <translation>Coping sorted BAM</translation>
    </message>
    <message>
        <location filename="../src/PrepareToImportTask.cpp" line="133"/>
        <source>Creating BAM index</source>
        <translation>Creating BAM index</translation>
    </message>
    <message>
        <location filename="../src/PrepareToImportTask.cpp" line="171"/>
        <source>Unknown reference sequence format. Only FASTA is supported</source>
        <translation>Unknown reference sequence format. Only FASTA is supported</translation>
    </message>
    <message>
        <location filename="../src/PrepareToImportTask.cpp" line="176"/>
        <source>The detected reference sequence format is &apos;%1&apos;. Only FASTA is supported</source>
        <translation>The detected reference sequence format is &apos;%1&apos;. Only FASTA is supported</translation>
    </message>
</context>
<context>
    <name>U2::BAMFormat</name>
    <message>
        <location filename="../src/BAMFormat.cpp" line="52"/>
        <source>BAM File</source>
        <translation>BAM файл</translation>
    </message>
</context>
</TS>
